<?php

namespace Angrycode\WappiRegister;

use Bitrix\Main\Config\Option;
use Bitrix\Main\Error;
use Bitrix\MessageService\Sender\Base;
use Bitrix\MessageService\Sender\Result\SendMessage;
use Bitrix\Main\Localization\Loc;


class Wappi extends Base
{ 
  private $login;

  private $password;
 
  private $provider;

  private $client;

  public function __construct()
  {
    $this->profileID = Option::get('angrycode.wappiregister', "PROFILE_ID", '');
    $this->token = Option::get('angrycode.wappiregister', "TOKEN", '');
    
    if (!empty($this->profileID) && !empty($this->token)) {
      $this->client = new WappiApi($this->profileID, $this->token);
      
    }
  }

  public function sendMessage(array $messageFields)
  {
    Loc::loadMessages(__FILE__);
    if (!$this->canUse()) {
      $result = new SendMessage();
      $result->addError(new Error(Loc::getMessage('ANGRYCODE_WAPPIREGISTER_SENDMESSAGE_ERROR')));
      return $result;
    }

    // 'phones' => $messageFields['MESSAGE_TO'],
    $parameters = [
      'recipient' => $messageFields['MESSAGE_TO'],
      'body' => "".self::cp1251_to_utf8($messageFields['MESSAGE_BODY'])."",
    ]; 

   

    $result = new SendMessage();
    $response = $this->client->send($parameters);

    if (!$response->isSuccess()) {
      $result->addErrors($response->getErrors());
      return $result;
    }

    return $result;
  }

  static function cp1251_to_utf8($s)
  {
    if ((mb_detect_encoding($s, 'UTF-8,CP1251')) == "WINDOWS-1251") {
      $c209 = chr(209);
      $c208 = chr(208);
      $c129 = chr(129);
      for ($i = 0; $i < strlen($s); $i++) {
        $c = ord($s[$i]);
        if ($c >= 192 and $c <= 239) $t .= $c208 . chr($c - 48);
        elseif ($c > 239) $t .= $c209 . chr($c - 112);
        elseif ($c == 184) $t .= $c209 . $c209;
        elseif ($c == 168) $t .= $c208 . $c129;
        else $t .= $s[$i];
      }
      return $t;
    } else {
      return $s;
    }
  }

  public function getShortName()
  {
    return 'WAPPI';
  }

  public function getId()
  {
    return 'WAPPI';
  }

  public function getName()
  {
    return Loc::getMessage('ANGRYCODE_WAPPIREGISTER_SMSC_NAME');
  }

  public function canUse()
  {
    return true;
  }

  public function getFromList()
  {
    $response = [array('id' => 'WAPPI', 'name' => 'WAPPI')];

    return $response;
  }
}