<?php

namespace Angrycode\WappiRegister;


use Bitrix\Main\ArgumentException;
use Bitrix\Main\Error;
use Bitrix\Main\Result;
use Bitrix\Main\Web\HttpClient;
use Bitrix\Main\Web\Json;
use \Bitrix\Main\Data\Cache;

use Bitrix\Main\Localization\Loc;

Loc::loadMessages(__FILE__);

class WappiApi
{
  private $profileID;

  private $token;

  public function __construct($profileID, $token)
  {
    $this->profileID = $profileID;
    $this->token = $token;
  }

  public function getSenderList()
  {
    $result = new Result();
    
    $response = [];
    
      $senders = [];
      

      $senders[] = [
        'id' => 'wappi',
        'name' => 'WAPPI'
      ];

      $result->setData($senders);
    

    return $result;
  }

  private function query($method, $parameters = [], $httpMethod = HttpClient::HTTP_POST)
  {
    $result = new Result();

    
    // $parameters['psw'] = $this->password;
    // $parameters['fmt'] = 3;

    $http = new HttpClient();
    
    $http->setHeader('Content-Type', 'application/json', true);
    $http->setHeader('Authorization', $this->token, true);
    if ($httpMethod === HttpClient::HTTP_GET) {
      $parameters['profile_id'] = $this->profileID;  
      $http->get('https://wappi.pro/api' . $method . '?'. http_build_query($parameters));

    } else {
      $http->post( 'https://wappi.pro/api' . $method .'?profile_id='.$this->profileID, json_encode($parameters));
    }

    // print_r($http->getResult());
    // die();
// die($http->getEffectiveUrl());
    try {
      
      $data = Json::decode($http->getResult());
      if ($data['status'] == 'error') {
        $result->addError(new Error($data['detail']));

        return $result;
      }

      $result->setData($data);
    } catch (ArgumentException $e) {
      
    }

    return $result;
  }

  public function send($parameters)
  {
    $result = new Result();

    $response = $this->query('/sync/message/send', $parameters);
    
    if (!$response->isSuccess()) {
      $result->addErrors($response->getErrors());
    }else if($response->getData()['status'] !== 'done'){
      $result->addErrors(array(new \Bitrix\Main\Error(GetMessage("ANGRYCODE_WAPPIREGISTER_OSIBKA_OTPRAVKI_SOOB"))));
    }


    return $result;
  }

  public function getStatus()
  {
    $result = new Result();

    $response = $this->query('/sync/get/status', array(), HttpClient::HTTP_GET);
    if (!$response->isSuccess()) {
      $result->addErrors($response->getErrors());
    }

    $result->setData($response->getData());

    return $result;
  }
}